openFullScreenIntentSettings static method

Future<bool> openFullScreenIntentSettings()

Opens the system "Full screen notifications" page for this app.

Returns false when there is nothing to open (below Android 14) or when no activity on the device handles the intent.

Implementation

static Future<bool> openFullScreenIntentSettings() async {
  try {
    final result =
        await _channel.invokeMethod<bool>('openFullScreenIntentSettings');
    return result ?? false;
  } on PlatformException catch (e) {
    debugPrint("Error invoking openFullScreenIntentSettings: ${e.message}");
    return false;
  } on MissingPluginException {
    return false;
  }
}